===================
pychemcurv.geometry
===================

.. automodule:: pychemcurv.geometry


.. autofunction:: pychemcurv.geometry.center_of_mass


.. autofunction:: pychemcurv.geometry.circum_center


.. autofunction:: pychemcurv.geometry.get_plane


.. autofunction:: pychemcurv.geometry.get_dihedral